<!DOCTYPE html>
<html>
<head>
    <title>Custom Admin</title>
    {% load static %}
    <link rel="stylesheet" href="{% static 'admin/css/base.css' %}">
</head>
<body>
    <div class="container">
        {% block content %}{% endblock %}
    </div>
</body>
</html>
