<div class="card shadow-sm border-0">
  <div class="card-body">
    <h6 class="card-title text-muted">{{ title|default:"Card Title"}}</h6>
    <h3>{{ content|default:"Card content" }}</h3>
  </div>
</div>