{% load i18n static palette %}
<!DOCTYPE html>
{% get_current_language as LANGUAGE_CODE %}{% get_current_language_bidi as LANGUAGE_BIDI %}
<html lang="{{ LANGUAGE_CODE|default:"en-us" }}" dir="{{ LANGUAGE_BIDI|yesno:'rtl,ltr,auto' }}">
<head>
  <title>{% block title %}Admin{% endblock %}</title>
  {% block stylesheet %}
    <link rel="stylesheet" href="{% static "palette/css/base.css" %}">
  {% endblock %}
  
  <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
  <link href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.5/font/bootstrap-icons.css" rel="stylesheet">

  {% block dark-mode-vars %}{% endblock %}
  {% block extrastyle %}{% endblock %}
  {% block extrahead %}{% endblock %}
  {% block responsive %}
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
  {% endblock %}
  {% block blockbots %}<meta name="robots" content="NONE,NOARCHIVE">{% endblock %}
</head>

<body>
  {% block body %}
  
  {% endblock body %}
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>

